#
# spec file for package yast2-samba-server
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-samba-server
Version:        5.0.1
Release:        1.3
URL:            https://github.com/yast/yast-samba-server
Summary:        YaST2 - Samba Server Configuration
Group:          System/YaST
License:        GPL-2.0-only

Source0:        %{name}-%{version}.tar.bz2

# Service.Active
BuildRequires:  pkgconfig(smbclient)
BuildRequires:  perl-Crypt-SmbHash
BuildRequires:  perl-X500-DN
BuildRequires:  update-desktop-files
# Yast2::ServiceWidget
BuildRequires:  yast2 >= 4.1.0
BuildRequires:  yast2-devtools >= 4.2.2
BuildRequires:  yast2-ldap
BuildRequires:  yast2-perl-bindings
BuildRequires:  yast2-users

# Test suite
BuildRequires:  rubygem(%{rb_default_ruby_abi}:yast-rake)
BuildRequires:  rubygem(%{rb_default_ruby_abi}:rspec)

Requires:       perl-Crypt-SmbHash
# Yast2::ServiceWidget
Requires:       yast2 >= 4.1.0
Requires:       yast2-ldap >= 3.1.2
Requires:       yast2-network
Requires:       yast2-perl-bindings
# samba-client/routines.rb
Requires:       yast2-samba-client >= 3.1.15
Requires:       yast2-ruby-bindings >= 1.0.0
Requires:       yast2-users

# bnc #386473, recommend yast2-samba-server when installaing these packages
Supplements:    samba

Supplements:    autoyast(samba-server)

BuildArch:      noarch

%description
This package contains the YaST2 component for Samba server
configuration.

%prep
%setup -q

%check
rake test:unit

%build
%yast_build

%install
%yast_install
%yast_metainfo

%files
%{yast_yncludedir}
%{yast_ydatadir}
%{yast_clientdir}
%{yast_moduledir}
%{yast_desktopdir}
%{yast_metainfodir}
%{yast_schemadir}
%{yast_icondir}
%doc %{yast_docdir}
%license COPYING

%changelog
* Mon Feb  3 2025 Samuel Cabrero <scabrero@suse.de>
- Remove nscd-related code (bsc#1236308)
- 5.0.1
* Wed Aug 30 2023 Josef Reidinger <jreidinger@suse.cz>
- 5.0.0 (bsc#1185510)
* Fri Mar  3 2023 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.6.0 (bsc#1208913)
* Wed Apr  6 2022 Ladislav Slezák <lslezak@suse.cz>
- Bump version to 4.5.0 (bsc#1198109)
* Wed Feb  2 2022 Samuel Cabrero <scabrero@suse.de>
- Remove libsmbclient-devel BuildRequires in favor of
  pkgconfig(smbclient); (jsc#SLE-20577);
- 4.4.2
* Thu Jan 27 2022 Noel Power <nopower@suse.com>
- Replace use of PackageSystem with Package to avoid core dumps;
  (bsc#1195182).
- 4.4.1
* Tue Apr 20 2021 Ladislav Slezák <lslezak@suse.cz>
- 4.4.0 (bsc#1185510)
* Wed Feb 17 2021 Josef Reidinger <jreidinger@suse.com>
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893).
- 4.3.4
* Tue Aug 11 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(samba-server) into the spec file
  in order to install this packages if the section has been defined
  in the AY configuration file (bsc#1146494).
- 4.3.3
* Mon Jun  1 2020 Martin Vidner <mvidner@suse.com>
- Autoyast schema: corrected problems in 'disabled' and 'share'
  (bsc#1170886)
- 4.3.2
* Wed May 27 2020 David Diaz <dgonzalez@suse.com>
- Dropped legacy testsuite (related to bsc#1138668).
- 4.3.1
* Tue May 12 2020 josef Reidinger <jreidinger@localhost>
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.0
* Wed Mar 11 2020 Knut Anderssen <kanderssen@suse.com>
- Fix check of connected users when proposing the default service
  action (bsc#1166303)
- 4.2.4
* Thu Mar  5 2020 Knut Anderssen <kanderssen@suse.com>
- Propose to restart samba services by default when writing the
  configuration with services already running. Reload is still used
  if some user is connected to the samba server (bsc#1165638)
- 4.2.3
* Thu Nov 28 2019 Knut Anderssen <kanderssen@suse.com>
- Fix failing Samba.GetServiceStatus old testsuite forcing and
  import of 'Directory' (bsc#1155923)
- 4.2.2
* Mon Nov 11 2019 Knut Anderssen <kanderssen@suse.com>
- Fix failing old testsuite (bsc#1155923)
- 4.2.1
* Fri May 31 2019 Stasiek Michalski <hellcp@mailbox.org>
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.0
* Wed Dec 12 2018 Josef Reidinger <jreidinger@suse.com>
- always use absolute path to binaries (bsc#1118291)
- properly escape shell arguments (bsc#1118291)
- 4.1.3
* Mon Nov 26 2018 Noah Davis <noahadvs@gmail.com>
- Provide icon with module (boo#1109310)
- 4.1.2
* Tue Oct 16 2018 schubi@suse.de
- Added license file to spec.
* Wed Sep  5 2018 Samuel Cabrero <scabrero@suse.de>
- Fix configuration not saved after new service status management
  (bsc#1106876)
- 4.1.1
* Mon Aug 20 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Mon Aug 13 2018 dgonzalez@suse.com
- Use Yast2::ServiceWidget to manage the service status
  (part of fate#319428)
- 4.1.0
* Mon Aug 13 2018 igonzalezsosa@suse.com
- Fix package building with yast2 4.0.84 (bsc#1104644).
- 4.0.4
* Fri Aug  3 2018 igonzalezsosa@suse.com
- Fix package building with yast2 4.0.80 (bsc#1103691).
- 4.0.3
* Thu Jun 28 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.0.2
* Thu Mar  1 2018 knut.anderssen@suse.com
- Use firewalld samba service definition (bsc#1083456)
- 4.0.1
* Mon Feb  5 2018 knut.anderssen@suse.com
- SuSEFirewall2 replaced by firewalld (fate#323460)
- 4.0.0
* Wed Jul 26 2017 scabrero@suse.com
- Drop NT style PDC/BDC configuration wizard (fate#323806)
- 3.2.2
* Mon Apr  3 2017 nopower@suse.com
- fix duplicated key warnings (bsc#1031613).
- Don't require install of cups for yast samba-server
  (bsc#1024670).
- 3.2.1
* Thu Mar 16 2017 kanderssen@suse.com
- Fix string comparisons in SambaBackendLDAP.pm and YaPI/Samba.pm
  (bsc#1029528)
- 3.2.0
* Tue Jun  7 2016 igonzalezsosa@suse.com
- Stop generating autodocs (fate#320356)
- 3.1.16
* Tue Apr 26 2016 igonzalezsosa@suse.com
- Fix outdated message regarding smb and nmb services restart
  (bsc#975880).
- 3.1.15
* Wed Mar 23 2016 lmuelle@suse.com
- Don't require libsmbclient as it's pulled in by libsmbclient-devel;
  (bsc#972197).
- 3.1.14
* Mon Nov 16 2015 igonzalezsosa@suse.com
- Fix validation of AutoYaST profiles (bsc#954412)
- 3.1.13
* Tue Jan 13 2015 nopower@suse.com
- When joining domain provide osName & osVer arguments to "net ads join"
  (bnc#873922).
- 3.1.12
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Wed Nov 12 2014 nopower@suse.com
- Squash "Possible precedence issue with control flow operator
  warning; (bnc#901597)
- 3.1.11
* Fri Jul 25 2014 ddiss@suse.com
- Ensure CUPS is installed if printer sharing is configured; (bnc#873703).
- 3.1.10
* Sun Jul  6 2014 noel.power@suse.com
- Fix duplicated 'Firewall Settings' string on Startup tab; (bnc#884058)
- 3.1.9
* Tue May  6 2014 mfilka@suse.com
- Adapted testsuite to last changes in Service module.
- 3.1.8
* Tue Apr 22 2014 locilka@suse.com
- Deprecated Service method calls replaced with new ones
- 3.1.7
* Fri Mar 28 2014 vmoravec@suse.com
- Fix failing testsuite
- 3.1.6
* Thu Mar 27 2014 ddiss@suse.com
- Refer to vfs_snapper and vfs_btrfs man pages in help text; (bnc#870570).
- Default to a standalone server instead of a PDC; (bnc#870669).
- 3.1.5
* Thu Mar  6 2014 vmoravec@suse.com
- Fix tests and add url to spec
- 3.1.4
* Fri Feb 14 2014 jsuchome@suse.cz
- enable LDAP widgets (bnc#856118)
- 3.1.3
* Fri Jan 31 2014 varkoly@suse.com
- Change requirement from yast2-ldap-client to yast2-ldap
- 3.1.2
* Wed Nov 13 2013 jreidinger@suse.com
- Add explicit COPYING file
* Thu Sep 19 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Fri Sep 13 2013 ddiss@suse.com
- Add "Utilize Btrfs Features" checkbox for shares.
- 3.0.3
* Fri Sep 13 2013 jsuchome@suse.cz
- check if Share value was changed by Browse button
- added help text, renamed Snapper checkbox
- 3.0.2
* Thu Sep 12 2013 jsuchome@suse.cz
- added "Snapper Support" checkbox for shares (fate#313349)
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Mon Jul  1 2013 jsuchome@suse.cz
- sort arrays so the test output is deterministic
- 2.24.1
* Fri Apr 19 2013 jsuchome@suse.cz
- testsuite adapted to last change of Service.ycp
- 2.24.0
* Tue Feb 19 2013 jsuchome@suse.cz
- Shares table:  show share specific guest access status, added
  button to toggle the it (bnc#803512)
- 2.23.2
* Thu Jan 31 2013 tgoettlicher@suse.de
- Fixed test suite
- 2.23.1
* Fri Jan  4 2013 locilka@suse.com
- Testsuites adapted to switching Service module to systemd
  (yast2-2.23.15)
- 2.23.0
* Wed May  9 2012 jsuchome@suse.cz
- enhanced check for password requirement in Users plugin
- 2.22.3
* Thu Mar 29 2012 jsuchome@suse.cz
- merge proofread texts
- 2.22.2
* Mon Mar 26 2012 jsuchome@suse.cz
- adpated for recent changes in FileUtils.ycp
- 2.22.1
* Wed Jan 25 2012 jsuchome@suse.cz
- confirmed license
- 2.22.0
* Thu Sep 22 2011 visnov@suse.cz
- set dialog title
- 2.21.4
* Tue Sep 13 2011 lslezak@suse.cz
- updated testsuite (systemd support) (bnc#664548)
- 2.21.3
* Mon Sep 12 2011 jsuchome@suse.cz
- corrected service names in testsuites (thanks to lslezak)
- 2.21.2
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Tue Apr  5 2011 jsuchome@suse.cz
- set "Allow Guest Access" option (bnc#621618)
- 2.21.1
* Wed Mar 30 2011 jsuchome@suse.cz
- adapted help text in first dialog (bnc#579992)
* Mon Mar 28 2011 jsuchome@suse.cz
- removed obsolete On value from 'ldap ssl' option
- added help texts for LDAP settings (bnc#531523)
- 2.21.0
* Mon Jan 10 2011 locilka@suse.cz
- Added 'samba-client' firewall service to list of services
  required to be open during firewall configuration (BNC #541958)
- 2.20.2
* Fri Jan  7 2011 locilka@suse.cz
- 'switch' wiped out (BNC #635820)
* Thu Jan  6 2011 locilka@suse.cz
- Added 'netbios-server' firewall service to list of services
  required to be open during firewall configuration (BNC #541958)
- 2.20.1
* Tue Jan  4 2011 locilka@suse.cz
- Also accepting samba-gplv3 packages (BNC #657414)
* Fri Feb 19 2010 locilka@suse.cz
- Re-added possibility to allow guest access (BNC #579993).
- Fixed buggy behavior when security settings were manually
  changed by user in advanced options (BNC #553349).
- Adjusted help according the current UI (BNC #580102).
- 2.18.3
* Mon Jan 25 2010 locilka@suse.cz
- Import sets Modified to true (BNC #572670).
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Wed Sep 16 2009 jsuchome@suse.cz
- use correct names for LDAP keys in add_machine.ycp (bnc#515991)
- 2.18.2
* Tue Jun 16 2009 mvidner@suse.cz
- Using autodocs-ycp.ami, which contains a fix for automake 1.11.
* Mon Mar 30 2009 locilka@suse.cz
- Enabling all expert settings that were hidden because of obsolete
  globals->ui_mode control file option (bnc #480820).
- 2.18.1
* Fri Jan 16 2009 locilka@suse.cz
- Enabling the UsersPlugin* for all configurations (bnc #460555).
- 2.18.0
* Wed Dec  3 2008 locilka@suse.cz
- Fixed LDAP Settings dialog layout (bnc #446794).
- 2.17.7
* Mon Dec  1 2008 locilka@suse.cz
- Using temporary file for pdbedit calls instead of stdin because
  pdbedit reads the input several times for one call (bnc #438481).
- 2.17.6
* Thu Nov  6 2008 locilka@suse.cz
- Using new service:samba-server firewall service (bnc #247344).
- 2.17.5
* Wed Nov  5 2008 locilka@suse.cz
- Adjusting module buttons according to YaST Style Guide
  (bnc #440538)
- 2.17.4
* Thu Oct 23 2008 locilka@suse.cz
- Dropping obsolete text from help (bnc #437350).
- 2.17.3
* Mon Sep  8 2008 locilka@suse.cz
- merged texts from proofread
* Fri Sep  5 2008 locilka@suse.cz
- Added WINS Hostname Resolution support (FATE #300971).
- 2.17.2
* Thu Sep  4 2008 locilka@suse.cz
- Adapted to yast2-ldap API changes (patch created by rhafer)
  (bnc #422524)
- Adjusted RPM dependencies.
- 2.17.1
* Tue Aug  5 2008 locilka@suse.cz
- Adjusted to the newest LDAP SCR agent (patch written by jsuchome)
  (FATE #303596).
- 2.17.0
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Tue May  6 2008 locilka@suse.cz
- YaST package now supplements: samba (bnc #386473).
- Dropped requirements for samba-pdb (bnc #387085).
- 2.16.3
* Tue Apr 15 2008 jsuchome@suse.cz
- adapted to new API of SambaNetJoin::Join
- 2.16.2
* Mon Apr 14 2008 locilka@suse.cz
- Unified Button Labels: OK instead of Accept (fate #120373).
- Fixed testsuites.
- 2.16.1
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Tue Dec  4 2007 locilka@suse.cz
- Merged proofread texts.
* Mon Oct 15 2007 locilka@suse.cz
- Correctly display user-shares status when adjusting it and
  switching between different tabs at one YaST run (#332838).
- Changing position of dialog buttons to fit the YaST Style Guide.
- Extended help for auth-sources.
- 2.16.0
* Tue Jun  5 2007 locilka@suse.cz
- Removed SambaNmbLookup::GetAvailableNeighbours call because this
  feature has been dropped from samba-client (#240045).
- 2.15.7
* Mon Apr 16 2007 locilka@suse.cz
- Added possibility to rename a share (#263302).
- 2.15.6
* Fri Apr 13 2007 locilka@suse.cz
- Disabling MySQL passdb backend which has not support in smb.conf
- Adjusting UI to allow set only one passdb backend
- Allowing multiple ldap-server entries in ldapsam backend
- Better parsing of passdb backend in SambaBackend module
- Better parsing of passdb backend in SambaBackendLDAP
* Wed Apr 11 2007 locilka@suse.cz
- Changing SambaServer functions to use only one "passdb backend"
  for the configuration (#245167).
- Adjusted testsuites.
- 2.15.5
* Wed Mar 21 2007 locilka@suse.cz
- Set SambaRole only when changed by user. This avoids rewriting
  changed made in Expert Settings (255824).
- 2.15.4
* Thu Mar  8 2007 locilka@suse.cz
- Adding a new feature 'Retrieve WINS Server via DHCP' to the UI.
  It enables or disables 'include = /etc/samba/dhcp.conf' in
  in smb.conf (FATE #120090).
- Adjusted Requires and BuildRequires.
- 2.15.3
* Wed Mar  7 2007 locilka@suse.cz
- Fixing UsersPluginSambaGroups not to redefine gettext functions
  and to work with 'strict' (#251857).
* Thu Mar  1 2007 locilka@suse.cz
- Fixing UsersPluginSambaGroups to be able to use translation
  macro __ (bugzilla #245786).
- 2.15.2
* Thu Feb 22 2007 locilka@suse.cz
- Fixed using icons in dialogs.
- 2.15.1
* Sun Jan 28 2007 locilka@suse.cz
- Removed some samba-client-related content confusingly left in
  samba-server.rnc definition. Patch made by Uwe Gansert (#239154).
- 2.15.0
* Tue Jan 16 2007 locilka@suse.cz
- Adding X-SuSE-YaST-AutoInstSchema entry into the application
  desktop file (#235342).
* Tue Nov 14 2006 locilka@suse.cz
- Fixed handling of undefined values (keys in hashes) in
  UsersPluginSambaGroups module (#220698).
- Fixed marking texts for translation to use double-underscore
  (#220698).
- Added new help, thanks to rhafer (#220698).
- 2.14.3
* Wed Nov  8 2006 locilka@suse.cz
- Fixed handling of "net rpc trustdom establish" when password
  contains quotes or apostrophes (#219001).
- Fixed evaluation of SambaTrustDom::Establish() function's return
  to show up that the command has failed (#219001).
- Added new testsuite for SambaTrustDom module.
- 2.14.2
* Fri Oct 27 2006 locilka@suse.cz
- Adding samba-server.rnc for AutoYaST profile validation (#215248)
- 2.14.1
* Tue Oct 10 2006 locilka@suse.cz
- Merged SLES10 SP1 branch to openSUSE 10.2.
- 2.14.0
* Mon Aug 28 2006 locilka@suse.cz
- Added yast2-ldap-client into BuildRequires.
- Changed call GetSharesTerm into SharesTerm (bugzilla #144787).
- 2.13.13
* Wed Jul 26 2006 locilka@suse.cz
- Function for creating path moved to yast2 package into the
  FileUtils module.
* Fri Jul 21 2006 locilka@suse.cz
- When creating a new share or editing an old one, the share-path
  is checked for its existency. If the path doesn't exists, it's
  offered to create it. Eventual errors, e.g., path is not
  a directory, cannot create path are reported (#186380).
- 2.13.12
* Thu May 11 2006 locilka@suse.cz
- Removing "ldap filter" from UI and functions, there is no such
  option (#169194).
- Adjusting testsuites to the last change.
- 2.13.11
* Mon Apr 10 2006 locilka@suse.cz
- Calling SambaAD::ReadADS() and SambaAD::ReadRealm() before
  the SambaNetJoin::Test() (#160056).
- 2.13.10
* Fri Apr  7 2006 locilka@suse.cz
- Ask user whether to propose the default configuration when user
  selects the LDAP support and has no values pre-filled (#163995).
- 2.13.9
* Thu Apr  6 2006 locilka@suse.cz
- Fixing add_machine.ycp script, SCR::Read() for smb.conf doesn't
  return "string" but "list <string>" (#163227)
- Running 'nscd -i passwd' instead of restarting the service
  (#163227).
- 2.13.8
* Mon Mar 13 2006 locilka@suse.cz
- Fixing bug #155708, changing focus in the LDAP configuration
  with every entered character because of instant password
  checking. Now the passwords are checked only once.
- 2.13.7
* Mon Mar 13 2006 locilka@suse.cz
- Adding net 'usershare' feature, bugzilla #143908
* Mon Mar  6 2006 locilka@suse.cz
- Adjusting BuildRequires for package
- 2.13.6
* Fri Jan 27 2006 locilka@suse.cz
- merged texts from proofreading
* Fri Jan 13 2006 locilka@suse.cz
- Added new functionality described in Bugzilla #120080
  When writing the configuration, Samba server is reloaded instead
  of restarted when there are some users currently connected.
  In this case, Samba admin is informed by a pop-up window to run
  `/etc/init.d/smb restart` and `/etc/init.d/nmb restart` despite
  the fact that users might be disconnected.
- Added also a new function returning connected users.
- 2.13.5
* Thu Jan 12 2006 locilka@suse.cz
- Fixed some typo in translated messages
- 2.13.4
* Thu Jan  5 2006 locilka@suse.cz
- Added SetFocus() functions for dialogs when user has to fill-up
  a password (Enhancement bugzilla #105219).
- 2.13.3
* Tue Dec 20 2005 jsuchome@suse.cz
- fixed testsuite failing due to recent changes in yast2-samba-client
- 2.13.2
* Mon Dec 19 2005 jsuchome@suse.cz
- merged texts from proofreading
- 2.13.1
* Fri Dec 16 2005 locilka@suse.cz
- fixed bug #133453, tdbdump has changed output syntax, adding
  support for the newer version and also leaving the old one
  supported.
- 2.13.0
* Mon Sep 19 2005 locilka@suse.cz
- fixed bug #49369, YaST had been changing SID when editing LDAP
* Thu Sep  1 2005 locilka@suse.cz
- fixed bug #106618, Forgotten text marked for getext tranlation.
- 2.12.8
* Mon Aug 29 2005 locilka@suse.cz
- fixed bug #106047, Samba server hadn't been started/stopped when
  the status was changed. Samba server wasn't restarted after
  writting changed settings.
- 2.12.7
* Sat Aug  6 2005 locilka@suse.cz
- fixed testsuites
- 2.12.6
* Tue Aug  2 2005 locilka@suse.cz
- fixed #78590, Export for AutoYaST didn't work
  adding some more imports
- 2.12.5
* Mon Aug  1 2005 locilka@suse.cz
- changed maintainer of the package
- fixed typo error #99443
- 2.12.4
* Mon Jun 27 2005 mlazar@suse.cz
- applied proofread texts
* Mon Jun 27 2005 mlazar@suse.cz
- fixed SambaTrustDom.pm
* Fri May 13 2005 mlazar@suse.cz
- 2.12.3
- fixed SambaSecrets.pm
- addede testsuite for SambaSecrets.pm
* Thu May 12 2005 mlazar@suse.cz
- 2.12.2
- fixed testsuites
- splited testsuites to two directories
* Fri Apr 22 2005 mlazar@suse.cz
- 2.12.1
- adapted to new interface of ProductFeatures.ycp
* Tue Mar 15 2005 mlazar@suse.cz
- fixed AskForJoin dialog
* Tue Mar 15 2005 mlazar@suse.cz
- SambaServer.pm: updated Read()/Write() progress bar
- wizards, dialaog-items.ycp: clean-up
* Mon Mar 14 2005 mlazar@suse.cz
- fixed progress status indicator in Read()/Write()
* Fri Mar 11 2005 mlazar@suse.cz
- SambaRole.pm: avoid use Switch; better error handling
- added perl testsuites for SambaRole.pm
* Fri Mar 11 2005 mlazar@suse.cz
- SambaService.pm: fixed Import(), better error handling
- added perl testsuites for SambaService.pm
* Fri Mar 11 2005 mlazar@suse.cz
- SambaAccount.pm: use Crypt::SmbHash to store passwords in Export/Inport
- added perl testsuite for SambaAccount.pm
* Fri Mar 11 2005 mlazar@suse.cz
- fixed Read/Write firewall settings
* Fri Mar  4 2005 mlazar@suse.cz
- addeded missing "&", "<p>", "$Id", headers, ...
* Fri Mar  4 2005 mlazar@suse.cz
- SambaRole.pm: fixed typo: preffered master -> preferred master
- updated testsuites
* Thu Mar  3 2005 mlazar@suse.cz
- fixed bugs in SambaAccount::Write()
* Thu Mar  3 2005 mlazar@suse.cz
- fixed function SambaRole::getLocalSID()
* Tue Mar  1 2005 mlazar@suse.cz
- adapted to yast2-samba-client 2.12.0
* Fri Feb 25 2005 mlazar@suse.cz
- updated testsuites
- 2.12.0
* Fri Feb 18 2005 mlazar@suse.cz
- ldap-widget.ycp: fixed typo
* Wed Feb 16 2005 mlazar@suse.cz
- fixed bug 50736 (save samba root password to autoyast control file)
- 2.11.7
* Mon Feb 14 2005 mlazar@suse.cz
- 2.11.6
- updated testsuites
* Tue Feb  8 2005 jsuchome@suse.cz
- merged texts from proofreading
- 2.11.5
* Mon Jan 31 2005 mlazar@suse.cz
- enabled firewall
- 2.11.4
* Mon Jan 31 2005 mlazar@suse.cz
- fixed testsuites
- 2.11.3
* Thu Jan 27 2005 mlazar@suse.cz
- fixed testsutes
- 2.11.2
* Tue Jan 25 2005 mlazar@suse.cz
- Progress::on()/off() replaced with Progress::set()
* Tue Jan 25 2005 mlazar@suse.cz
- removed dependence on yast2-firewall
* Fri Jan 21 2005 mlazar@suse.cz
- 2.11.1
- fixed testsute
- removed ldap expert setting buttons
* Wed Dec 29 2004 mlazar@suse.cz
- fixed many bugs in Samba LDAP Settings
* Thu Dec 23 2004 mlazar@suse.cz
- fixed LDAP support
- added Samba LDAP Settings tab
- added Samba LDAP Expert Settings dialog
* Fri Dec 10 2004 mlazar@suse.cz
- abort button works now
* Fri Nov 19 2004 mlazar@suse.cz
- fixed some typo
- update testsuite
* Tue Nov 16 2004 mlazar@suse.cz
- writeable parametr replaced with inverted synonym "read only"
- added "inherit ACLS" parametr (see bug #39656)
* Mon Nov 15 2004 mlazar@suse.cz
- fixed typo: GlobalSetStr => GlobalGetStr
* Mon Nov 15 2004 mlazar@suse.cz
- added writable flag to shares list and Add Share dialog (#39656)
* Fri Nov 12 2004 mlazar@suse.cz
- fixed CWM handlers
* Thu Nov 11 2004 mlazar@suse.cz
- fixed typo "lasp passwd sync" => "ldap passwd sync"
* Thu Nov 11 2004 mlazar@suse.cz
- avoid select()
- avoid computed arguments in sprintf()
* Wed Nov 10 2004 mlazar@suse.cz
- fixed YaPI
* Mon Nov  8 2004 mlazar@suse.cz
- 2.11.0
- SambaServer.ycp transformed to peral and splited to
  SambaAccounts.pm, SambaBackend.pm, SambaBackendLDAP.pm,
  SambaBackendSimple.pm, SambaPrinters.pm, SambaRole.pm,
  SambaSecrets.pm, SambaServices.pm and SambaTrustDom.pm
* Mon Oct  4 2004 mlazar@suse.cz
- fixed #45588 - Samba Server Configuration not shown in Summary in autoyast
* Mon Sep 20 2004 mlazar@suse.cz
- updated testsuite
- 2.10.7
* Fri Sep 17 2004 mlazar@suse.cz
- fixed Bugzilla Bug 45380: samba-server backend handler not implemented
* Tue Sep 14 2004 mlazar@suse.cz
- adapted testsuite to changes in yast2-firewall
* Tue Sep 14 2004 mlazar@suse.cz
- fixed testsuite
* Mon Sep 13 2004 mlazar@suse.cz
- 10.2.6
* Thu Sep  9 2004 mlazar@suse.cz
- Required replaced by PackageSystem (see bug 30872)
* Mon Sep  6 2004 mlazar@suse.cz
- 10.2.5
- Added GetModified, SetModified for autoyast
* Mon Aug 30 2004 mlazar@suse.cz
- 10.2.4
* Mon Aug 30 2004 mlazar@suse.cz
- fixed Bugzilla Bug 44175 - Unable to complete enabling Samba Server
  service through YaST
* Fri Aug 27 2004 visnov@suse.cz
- merged proofread texts
* Wed Aug 18 2004 mlazar@suse.cz
- 2.10.3
- fixed Bugzilla Bug 41402 - Don't add unset/ unused default options
- fixed Bugzilla Bug 40059 - mark disabled share as 'disabled by YaST'
- fixed bug when delete item in expert settings
- updated testsuite
- fixed return value for CommandLine::Run()
* Tue Aug 17 2004 jsuchome@suse.cz
- plugin for users and groups only available in expert mode
* Mon Aug 16 2004 mlazar@suse.cz
- fixed testsuite
* Mon Aug 16 2004 mlazar@suse.cz
- Makefile fix
- 2.10.2
* Mon Aug 16 2004 mlazar@suse.cz
- changed TablePopup::CreateTableDescr attributes
- no WINS widget initialization when ui_mode is "simple"
* Fri Aug 13 2004 mlazar@suse.cz
- used CWMTab module
- StartUp custom widget replaced by CWMServiceStart and
  CWMFirewallInterface widgets
- Identity custom widget splited to BaseSettings, WinsSetting,
  NetbiosName and AdvancedSettings custom widgets
- help modified to respect chanes in UI
- Instalation_Step2 dialog simplified if ui_mode is "simple"
* Wed Aug 11 2004 mlazar@suse.cz
- code clean-up
* Wed Aug 11 2004 mlazar@suse.cz
- firewall support
* Tue Aug 10 2004 mlazar@suse.cz
- integrated proofreading (proofed-2004-08-09.tar.gz)
* Mon Aug  9 2004 mlazar@suse.cz
- LdapServer module replaced by LdapServerAccess
- addeded firewall to UI and to #neededforbuild list
- Simplified UI when ProductFeatures::ui_mode is "simple"
- 2.10.1
* Wed Jun 23 2004 visnov@suse.cz
- missing marks of text for translation (#41404)
* Mon Jun  7 2004 rhafer@suse.de
- users-plugin: plugin can be removed when adding a new user (#41645)
* Fri Jun  4 2004 visnov@suse.cz
- even if smb.conf does not contain "ldap suffix", create LDAP objects if necessary (#41633)
- 2.9.28
* Tue Jun  1 2004 visnov@suse.cz
- in retry, handle correct success (do not avoid too many LDAP connections) - 41400
- 2.9.27
* Mon May 31 2004 visnov@suse.cz
- properly initialize LDAP before creating LDAP objects (#41398)
- allow to retry LDAP server connection after its restart (#41400)
- create also idmap suffix object (#41306)
- 2.9.26
* Wed May 26 2004 visnov@suse.cz
- create root account if not exists (#41182)
- setup ACLs for Samba (#41210)
- setup and create if needed machine LDAP suffix (#41183)
- adding indices into slapd.conf, if needed (#41165)
- 2.9.25
* Mon May 24 2004 visnov@suse.cz
- fixed testsuite
- 2.9.24
* Sun May 23 2004 nashif@suse.de
- temp. diasble testuite
- 2.9.23
* Thu May 20 2004 visnov@suse.cz
- use secrets.tdb instead of RPC call for trusted domains (#40732)
- added version and capabilities info to YaPI (#40796)
- try to bind before setting LDAP password (#40809)
- write LDAP settings before storing LDAP password (#40866)
- propose LDAP URL when adding a new passdb backend (#40849)
- improve "add machine" script for LDAP (#40365)
- 2.9.22
* Wed May 19 2004 visnov@suse.cz
- also setup home directory for machine accounts (#40365)
* Thu May 13 2004 visnov@suse.cz
- if using common LDAP setup, update users plugin list (#40509)
- 2.9.21
* Thu May 13 2004 rhafer@suse.de
- users-plugin don't abort when adding new user and SID couldn't
  be read (#40508)
- return an error message requesting password change when adding
  a samba account to an existing user (#40419)
* Thu May 13 2004 visnov@suse.cz
- synchronization between Expert options and Authentication Sources dialogs fixed
- for LDAP use own script for "add machine script" (#40365)
* Tue May 11 2004 visnov@suse.cz
- use Shares tab as a default when configuration is changed (#40058)
- refix - remove duplicated warning (#40154)
- cleanup autoyast summary (#40311)
- don't show warning is netbios name was empty or in autoyast (#40312)
- fix gettext use in users-plugin (#40160)
- fix autoyast (#40314, #40310, #40315)
- refix schema installation (#40034)
- handle empty share table correctly (#40349)
* Mon May 10 2004 visnov@suse.cz
- fix neededforbuild and requires
- 2.9.20
* Mon May 10 2004 visnov@suse.cz
- install samba3.schema if using local LDAP server - added yast2-ldap-server to neededforbuild and requires (#40034)
- use "net getlocalsid" to initialize SID (#40034)
- fix wizard to handle authentication details dialog correctly (#40146)
- duplicate the workgroup info in global settings (#40149)
- select the correct tab in Qt (#40137)
- merged proofread texts
- don't allow to add an already existing share (#40235)
- show only warning with the longest path prefix (#40154)
- always ask before abort (#40240)
- don't create "server string" if not present already (#40056)
* Thu May  6 2004 visnov@suse.cz
- 2.9.19
* Wed May  5 2004 visnov@suse.cz
- use proper tab widget if available
- don't start wizard if the config file is changed (#39779)
- restore workgroup in wizard if clicked next/back (#39779)
- YaPI::Samba implementation fixes (#39971)
* Tue May  4 2004 rhafer@suse.de
- users-plugin: disabled debugging output
- users-plugin: return appropriate error in initialization fails
- users-plugin: separated users and groups plugin
* Tue May  4 2004 visnov@suse.cz
- merged in the proofread texts
- cleanup buttons (#39779)
- show abort warning (#39779)
- complete list of known smb.conf options added (#39779)
- require ldap:// or ldaps:// scheme prefix for LDAP-based
  passdb backend (#38994)
- warn when using insecure path in a share (#39779)
- warn when netbios name changes (#39779)
- don't lookup the package if required packages installation failed
- store table data between tab switches (#39779)
* Thu Apr 29 2004 visnov@suse.cz
- help texts added
- dialog buttons fixes
- 2.9.18
* Wed Apr 28 2004 visnov@suse.cz
- Samba YaPI improved
- complete UI redesign
- plugin for Users module
- 2.9.17
* Wed Apr 21 2004 visnov@suse.cz
- propose correct bind_dn (#38993)
- don't split passdb backends by comma (breaks LDAP backends)
- Samba YaPI improved
- use Service
- 2.9.16
* Fri Apr  2 2004 visnov@suse.cz
- YaST2 is now GPL
- 2.9.15
* Fri Apr  2 2004 visnov@suse.cz
- properly detect enabled shares (#37941)
- 2.9.14
* Thu Apr  1 2004 visnov@suse.cz
- fix CWM-related warnings
- 2.9.13
* Wed Mar 31 2004 visnov@suse.cz
- removed obsolete code
- 2.9.12
* Mon Mar 22 2004 visnov@suse.cz
- 2.9.11
* Wed Mar 17 2004 visnov@suse.cz
- fix abort confirmation
* Wed Mar 17 2004 visnov@suse.cz
- finished help texts
- don't show help for passdb backend twice
* Mon Mar 15 2004 visnov@suse.cz
- use "mysql", not "mysqlsam" (#35393)
- install samba-pdb if needed
- compilation fixes
- adapt for new perl convention
- 2.9.10
* Wed Mar 10 2004 visnov@suse.cz
- don't log undef (#35523)
- 2.9.8
* Wed Mar 10 2004 nashif@suse.de
- Fixed for new wizard
* Mon Mar  8 2004 visnov@suse.cz
- add icon into wizard
* Mon Mar  8 2004 visnov@suse.cz
- pass correct values to share read/write (#35234)
- do not show internal values in share edit
- 2.9.7
* Sun Mar  7 2004 kkaempf@suse.de
- fix typing
- 2.9.6
* Mon Mar  1 2004 visnov@suse.cz
- merged back proofread texts
- use /var/lib/nobody for the add machine script (#35090)
- better type info
- 2.9.5
* Tue Feb 24 2004 visnov@suse.cz
- netbios name configuration (#34874)
* Mon Feb 23 2004 visnov@suse.cz
- 2.9.3
* Sat Feb 21 2004 schwab@suse.de
- Fix typo in specfile.
* Wed Feb 18 2004 visnov@suse.cz
- rewritten SAM support. Now multiple passdb backends can be configured
  (done as Perl module)
- better support for LDAP
- fix testsuites
- drop samba-client from requirements, install it on demand
- 2.9.2
* Mon Feb  9 2004 visnov@suse.cz
- remove "global"
- fix testsuite
- use "net getsid" instead of "smbpasswd -S"
- drop y2cc
- 2.9.1
* Fri Jan 30 2004 visnov@suse.cz
- first version for new interpreter
* Wed Oct 29 2003 visnov@suse.cz
- adapted for TablePopup
- fixed testsuite
- 2.9.0
* Fri Sep 19 2003 visnov@suse.cz
- fixed testsuite
- 2.8.17
* Thu Sep 18 2003 nashif@suse.de
- fixed testsuite
- 2.8.15
* Mon Sep 15 2003 nashif@suse.de
- Dont write configuration into running system if in config
  mode
- 2.8.14
* Mon Sep 15 2003 nashif@suse.de
- Call correct function name in autoinst mode
- 2.8.13
* Mon Sep 15 2003 msvec@suse.cz
- updated testsuite
- 2.8.12
* Mon Sep 15 2003 visnov@suse.de
- #30794: set the os level to 65
- yast2-installation in needed-for-build
- 2.8.11
* Mon Sep  8 2003 nashif@suse.de
- #32091: return list of required packages
- 2.8.10
* Mon Sep  8 2003 visnov@suse.de
- fix autoyast mode problems (#30161)
- 2.8.9
* Fri Sep  5 2003 visnov@suse.de
- merged in texts from proofread
- 2.8.8
* Wed Sep  3 2003 visnov@suse.de
- if the server is disabled, set the radio button of the would-be enabled role
* Wed Sep  3 2003 visnov@suse.de
- resolve PDC as PDC, not as standalone server (#29888)
* Fri Aug 29 2003 visnov@suse.de
- 2.8.7
* Tue Aug 26 2003 visnov@suse.de
- mark texts for translation
* Mon Aug 25 2003 visnov@suse.de
- Fix dialog init (#29243)
- Do not show empty error if not able to change LDAP password
- Do not save settings if not needed
- 2.8.6
* Thu Aug 21 2003 visnov@suse.de
- show error dialog if required packages are not installed before quit
* Wed Aug 20 2003 visnov@suse.de
- Do not show Initializing... dialog
* Tue Aug 19 2003 visnov@suse.de
- improve start dialog
- use Printer::checkSpooler
- 2.8.5
* Tue Aug 19 2003 nashif@suse.de
- Added yast2-packager to neededforbuild
* Mon Aug 11 2003 visnov@suse.de
- merged in proofread texts
- 2.8.3
* Fri Aug  8 2003 visnov@suse.de
- add Browse button for adding a share
- layout fixes
- do not depend on samba
- 2.8.2
* Tue Aug  5 2003 visnov@suse.de
- use LDAP system settings for defaults
- added desktop file
- 2.8.1
* Mon Jul 28 2003 visnov@suse.de
- fix package dependencies
* Thu May 29 2003 visnov@suse.cz
- initial version
- 2.8.0
